#----------------------------------------------------------
xMin=40
xMax=70
xPlage=c(xMin:xMax)
#----------------------------------------------------------
#Estimation non paramtrique des probabilits conditionnelles de sortie
t_ajust=subset(t,t$AgeEntree<t$AgeSortie)

#Kaplan-Meier pour la population globale
wH=survfit(Surv(AgeEntree,AgeSortie,non_censure,type="counting")~1,type="kaplan-meier",data=t_ajust,subset=Sexe=="M")
wF=survfit(Surv(AgeEntree,AgeSortie,non_censure,type="counting")~1,type="kaplan-meier",data=t_ajust,subset=Sexe=="F")

Q_H=getQx(wH,0,120)
Q_F=getQx(wF,0,120)

#Comparaison avec l'estimateur de Hoem pour contrle
Q_H_Hoem=rowSums(decesVentilesH)/rowSums(expoVentilesH)
Q_H_Hoem[is.na(Q_H_Hoem)]=0
Q_F_Hoem=rowSums(decesVentilesF)/rowSums(expoVentilesF)
Q_F_Hoem[is.na(Q_F_Hoem)]=0

sauveFigure()
par(mfrow=c(1,2))

plot(xPlage,Q_F[xPlage+1],xlab="Age",ylab="Qx F",type="l")
lines(xPlage,Q_F_Hoem[xPlage+1],col="red")
title("Femmes")
legend("topleft", legend = c("Taux KM","Taux Hoem"), col = c("black","red"), pch = 15, bty = "n", pt.cex = 1, cex = 0.8, horiz = F, inset = c(0.1, 0.1))

plot(xPlage,Q_H[xPlage+1],xlab="Age",ylab="Qx H",type="l")
lines(xPlage,Q_H_Hoem[xPlage+1],col="red")
title("Hommes")
legend("topleft", legend = c("Taux KM","Taux Hoem"), col = c("black","red"), pch = 15, bty = "n", pt.cex = 1, cex = 0.8, horiz = F, inset = c(0.1, 0.1))

dev.off()

#----------------------------------------------------------
#Comparaison EMV et approximation discrte (MCP) pour Thatcher

qAjusteH_MCP=qxAjuste(Q_H,rowSums(expoVentilesH),xMin,xMax,TRUE,"Thatcher")
pMCP=unlist(qAjusteH_MCP[1])
pInitial=c(pMCP[1],pMCP[2],log(pMCP[3]))
#qAjusteH_EMV=qThatcher(t_ajust[t_ajust$Sexe=="M",])
qAjusteH_EMV=qThatcher(t_ajust[t_ajust$Sexe=="M",],pInitial)
pEMV=unlist(qAjusteH_EMV[1])

sauveFigure()
plot(xPlage,Q_H[xPlage+1],xlab="Age",ylab="Qx H")
lines(xPlage,unlist(qAjusteH_MCP[2])[xPlage+1],col="red")
lines(xPlage,unlist(qAjusteH_EMV[2])[xPlage+1],col="magenta")
title("EMV vs PMV")
legend("topleft", legend = c("Taux bruts","Thatcher MCP","Thatcher EMV"), col = c("black","red","blue","green","magenta"), pch = 15, bty = "n", pt.cex = 1, cex = 0.8, horiz = F, inset = c(0.1, 0.1))
dev.off()

cat("Paramtres du modle de Thatcher (approximation discrte)","\n")
# qx=1-exp(-a)*exp(-b/log(c)*(c-1)*c^x)
# qx=1-exp(-g)*((1+a*exp(b*(x+1)))/(1+a*exp(b*x)))^(-1/b)
pMCP=unlist(qAjusteH_MCP[1])
cat(c(pMCP[1],pMCP[3],pMCP[2]),"\n")
cat("Paramtres du modle de Thatcher (maximum de vraisemblance)","\n")
cat(c(pEMV[3],exp(pEMV[2]),pEMV[1]),"\n")

#----------------------------------------------------------
#Ajustement paramtrique (pour la population globale)
#NB : Les modles de Thatcher et Makeham conduisent au mme ajustement

tMortaliteF=LectureTM(paste(dossierTM,"/TF00-02.txt",sep=""))
tMortaliteH=LectureTM(paste(dossierTM,"/TF00-02.txt",sep=""))

qAjusteF_M=qxAjuste(Q_F,rowSums(expoVentilesF),xMin,xMax,TRUE,"Makeham")
qAjusteF_M2=qxAjuste(Q_F,rowSums(expoVentilesF),xMin,xMax,FALSE,"Makeham")
qAjusteF_L=qxAjusteLogit(Q_F,rowSums(expoVentilesF),xMin,xMax,TRUE,tMortaliteF$Qx)
qAjusteF_T=qThatcher(t_ajust[t_ajust$Sexe=="F",])
qAjusteH_M=qxAjuste(Q_H,rowSums(expoVentilesH),xMin,xMax,TRUE,"Makeham")
qAjusteH_M2=qxAjuste(Q_H,rowSums(expoVentilesH),xMin,xMax,FALSE,"Makeham")
qAjusteH_L=qxAjusteLogit(Q_H,rowSums(expoVentilesH),xMin,xMax,TRUE,tMortaliteH$Qx)
qAjusteH_T=qThatcher(t_ajust[t_ajust$Sexe=="M",])
qAjusteH_T2=qxAjuste(Q_H,rowSums(expoVentilesH),xMin,xMax,TRUE,"Thatcher")

#Affichage
sauveFigure()
par(mfrow=c(1,2))

plot(xPlage,Q_F[xPlage+1],xlab="Age",ylab="Qx F")
lines(xPlage,unlist(qAjusteF_M[2])[xPlage+1],col="red")
lines(xPlage,unlist(qAjusteF_M2[2])[xPlage+1],col="blue")
lines(xPlage,unlist(qAjusteF_L[2])[xPlage+1],col="green")
lines(xPlage,unlist(qAjusteF_T[2])[xPlage+1],col="magenta")
title("Femmes")
legend("topleft", legend = c("Taux bruts","Makeham MCP","Makeham MCO","Brass","Thatcher"), col = c("black","red","blue","green","magenta"), pch = 15, bty = "n", pt.cex = 1, cex = 0.8, horiz = F, inset = c(0.1, 0.1))

plot(xPlage,Q_H[xPlage+1],xlab="Age",ylab="Qx H")
lines(xPlage,unlist(qAjusteH_M[2])[xPlage+1],col="red")
lines(xPlage,unlist(qAjusteH_M2[2])[xPlage+1],col="blue")
lines(xPlage,unlist(qAjusteH_L[2])[xPlage+1],col="green")
lines(xPlage,unlist(qAjusteH_T[2])[xPlage+1],col="magenta")
title("Hommes")
legend("topleft", legend = c("Taux bruts","Makeham MCP","Makeham MCO","Brass","Thatcher"), col = c("black","red","blue","green","magenta"), pch = 15, bty = "n", pt.cex = 1, cex = 0.8, horiz = F, inset = c(0.1, 0.1))

dev.off()
#----------------------------------------------------------
#Sauvegarde des tables ajustes
qAjusteH=unlist(qAjusteH_M[2])
lAjusteH=matrix(nrow=121,ncol=1,data=10^5)
colnames(lAjusteH)="Lx"
for (x in 2:121){
  lAjusteH[x]=lAjusteH[x-1]*(1-qAjusteH[x-1])  
}
write.table(lAjusteH,paste(dossierTables,"/LxAjuste_h.csv",sep=""), sep=";",row.names=FALSE, dec=sepDecimal)
write.table(qAjusteH,paste(dossierTables,"/QxAjuste_h.csv",sep=""), sep=";",row.names=FALSE, dec=sepDecimal)

qAjusteF=unlist(qAjusteF_T[2])
lAjusteF=matrix(nrow=121,ncol=1,data=10^5)
colnames(lAjusteF)="Lx"
for (x in 2:121){
  lAjusteF[x]=lAjusteF[x-1]*(1-qAjusteF[x-1])  
}
write.table(lAjusteF,paste(dossierTables,"/LxAjuste_f.csv",sep=""), sep=";",row.names=FALSE, dec=sepDecimal)
write.table(qAjusteF,paste(dossierTables,"/QxAjuste_f.csv",sep=""), sep=";",row.names=FALSE, dec=sepDecimal)

